from distutils.core import setup

setup (
    name = 'spider001',
    version = '1.0.0',
    py_modules = ['spider001'],
    author = 'jenny42',
    author_email = 'jenny42@mail.ustc.edu.cn',
    url = 'http://jenny42.com',
    description = 'A simple print of web page',
)